<?php
/**
* ơ֥ǥ륤󥿥ե
*
* PHP version 5
*
* @package    interfaces
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

interface ITableModel extends IModel
{
	/*
	 *   ơ֥̾
	 */
	public function getTableName();

	/*
	 *   ץ饤ޥꥭե̾
	 */
	public function getPrimaryKey();

	/*
	 *   ե̾
	 */
	public function getForeignKey( String $model_name );

	/*
	 *   Ÿեɤ
	 */
	public function getExtractField( String $model_name, String $field );

	/*
	 *   Ϣ
	 */
	public function getRelationList();

	/*
	 *   ơ֥ͭDTO
	 */
	public function createDTO();

}

return __FILE__;